from __future__ import annotations

from .FXWindow import FXWindow

#: Automatically gray out when not updated.
MENU_AUTOGRAY: int = hash("MENU_AUTOGRAY")

#: Automatically hide button when not updated.
MENU_AUTOHIDE: int = hash("MENU_AUTOHIDE")


class FXMenuCaption(FXWindow):
    """The menu caption is a widget which can be used as a caption above a number of menu commands in a menu."""



from __future__ import annotations

from .AFXDialog import AFXDialog
from .AFXGuiMode import AFXGuiMode
from .AFXGuiObjectManager import AFXGuiObjectManager
from .FXObject import FXObject


class AFXForm(AFXGuiMode):
    """Abaqus."""

    def __init__(self, owner: AFXGuiObjectManager):
        """Constructor.

        Parameters
        ----------
        owner : AFXGuiObjectManager
            Owner (a module or a toolset) of the form.
        """

    def activate(self):
        """Performs the necessary tasks when the form is activated.

        Reimplemented from AFXGuiMode.
        """

    def cancel(self, tgt: FXObject | None = None, msg: int = 0):
        """Requests a cancellation of the form. When the cancel operation completes, successfully or not, the
        target will be sent the given message. The message data pointer will be non-zero for successful
        cancellation and zero if the cancel operation was abandoned for some purpose.

        Parameters
        ----------
        tgt : FXObject | None
            Completion message target.
        msg : int
            Completion message ID.
        """

    def commit(self):
        """Performs the necessary tasks when the form is committed.

        Implements AFXGuiMode.
        """

    def continueMode(self):
        """Used to get the next dialog box in the mode.

        Implements AFXGuiMode.
        """

    def deactivateIfNeeded(self):
        """Deactivates the form if the user pressed the OK button of the currently posted dialog box.

        This method is called after the commands are processed successfully.
        """

    def getFirstDialog(self):
        """Returns the first dialog box to be posted."""

    def getNextDialog(self, previousDialog: AFXDialog):
        """Returns the next dialog box to be posted.

        Parameters
        ----------
        previousDialog : AFXDialog
            Previous dialog box.
        """

    def issueCommands(self, writeToReplay: bool = True, writeToJournal: bool = False):
        """Generates commands based on the current state, sends the commands, and deactivates the form if
        necessary. If the commands did not complete successfully, a dialog box will be posted with an error
        message.

        Parameters
        ----------
        writeToReplay : bool
            True if commands should be written to the replay file; False if not.
        writeToJournal : bool
            True if commands should be written to the journal file; False if not.
        """

    def setModal(self, postModalDialogs: bool):
        """Sets the modal state; if True, dialogs will be posted as modal. By default the form posts dialogs as
        non-modal.

        Parameters
        ----------
        postModalDialogs : bool
            True if the form should post dialogs as modal.
        """



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc

from ..UtilityAndView.abaqusConstants import SymbolicConstant
from .BoundaryConditionState import BoundaryConditionState


@abaqus_class_doc
class FluidCavityPressureBCState(BoundaryConditionState):
    """The FluidCavityPressureBCState object stores the propagating data for a fluid cavity pressure boundary
    condition in a step. One instance of this object is created internally by the FluidCavityPressureBC object
    for each step. The instance is also deleted internally by the FluidCavityPressureBC object. The
    FluidCavityPressureBCState object has no constructor or methods. The FluidCavityPressureBCState object is
    derived from the BoundaryConditionState object.

    .. note::
        This object can be accessed by::

            import load
            mdb.models[name].steps[name].boundaryConditionStates[name]

        The corresponding analysis keywords are:

        - BOUNDARY
    """

    #: A Float specifying the fluid cavity pressure magnitude.
    magnitude: float | None = None

    #: A SymbolicConstant specifying the propagation state of the fluid cavity pressure
    #: magnitude. Possible values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    magnitudeState: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the amplitude reference. Possible
    #: values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    amplitudeState: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the BoundaryConditionState object. Possible values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - PROPAGATED_FROM_BASE_STATE
    #: - MODIFIED_FROM_BASE_STATE
    #: - DEACTIVATED_FROM_BASE_STATE
    #: - BUILT_INTO_MODES
    status: SymbolicConstant

    #: A String specifying the name of the amplitude reference. The String is empty if the
    #: boundary condition has no amplitude reference.
    amplitude: str = ""



from __future__ import annotations

from .AFXCommand import AFXCommand
from .AFXGuiMode import AFXGuiMode


class AFXGuiCommand(AFXCommand):
    """This class is designed for the GUI commands processed by modes."""

    def __init__(self, mode: AFXGuiMode, method: str, objectName: str = "''", registerQuery: bool = False):
        """Constructor.

        Parameters
        ----------
        mode : AFXGuiMode
            Host mode.
        method : str
            Method.
        objectName : str
            Object name.
        registerQuery : bool
            True if a query should be registered so that the command's keyword values can be updated based on the kernel state.
        """

    def getMode(self):
        """Retrieves the command's mode."""



from __future__ import annotations

from .FXObject import FXObject


class FXId(FXObject):
    """Encapsulates server side resource."""

    def create(self):
        """Create resource.

        Reimplemented in FXBitmap, FXColorBar, FXColorSelector, FXColorWell, FXColorWheel, FXComboBox,
        FXComposite, FXCursor, FXDirBox, FXDirList, FXDockTitle, FXDriveBox, FXFileList, FXFont,
        FXFontSelector, FXGLCanvas, FXGLContext, FXGLViewer, FXGLVisual, FXGroupBox, FXHeader, FXIcon,
        FXIconList, FXImage, FXImageView, FXLabel, FXList, FXListBox, FXMDIChild, FXMenuButton,
        FXMenuCaption, FXMenuCascade, FXProgressBar, FXMenuTitle, FXOptionMenu, FXPrintDialog, FXRootWindow,
        FXScrollWindow, FXShell, FXSpinner, FXStatusline, FXTabBar, FXTable, FXText, FXTextField,
        FXToggleButton, FXToolbarShell, FXTooltip, FXTopWindow, FXTreeList, FXTreeListBox, FXVisual,
        FXWindow, AFXManagerMenuPane, AFXMainWindow, AFXPromptArea, AFXBaseTable, AFXColorButton,
        AFXColorFlyout, AFXComboBox, AFXDialog, AFXFloatSpinner, AFXFlyoutButton, AFXListBox, AFXNote,
        AFXOptionTreeItem, AFXPrimFloatSpinner, AFXProgressBar, AFXSpinner, AFXTable, AFXTextField, and
        AFXVerticalAligner.
        """

    def destroy(self):
        """Destroy resource.

        Reimplemented in FXBitmap, FXComboBox, FXComposite, FXCursor, FXDirBox, FXDirList, FXDriveBox,
        FXFileList, FXFont, FXGLCanvas, FXGLContext, FXGLVisual, FXIcon, FXImage, FXListBox, FXMenuCascade,
        FXOptionMenu, FXRootWindow, FXTreeList, FXTreeListBox, FXVisual, FXWindow, AFXManagerMenuCascade,
        AFXColorFlyout, and AFXTable.
        """

    def detach(self):
        """Detach resource.

        Reimplemented in FXBitmap, FXColorBar, FXColorWell, FXColorWheel, FXComboBox, FXComposite, FXCursor,
        FXDirBox, FXDirList, FXDockTitle, FXDriveBox, FXFileList, FXFont, FXGLCanvas, FXGLContext,
        FXGLViewer, FXGLVisual, FXGroupBox, FXHeader, FXIcon, FXIconList, FXImage, FXImageView, FXLabel,
        FXList, FXListBox, FXMDIChild, FXMenuButton, FXMenuCaption, FXMenuCascade, FXProgressBar,
        FXMenuTitle, FXOptionMenu, FXRootWindow, FXStatusline, FXTable, FXText, FXToggleButton, FXTooltip,
        FXTopWindow, FXTreeList, FXTreeListBox, FXVisual, FXWindow, AFXBaseTable, AFXColorFlyout,
        AFXFlyoutButton, AFXNote, and AFXTable.
        """

    def getApp(self):
        """Get application."""

    def getUserData(self):
        """Get user data pointer."""

    def id(self):
        """Get XID handle.

        Reimplemented in FXFont.
        """

    def setUserData(self, ptr: str):
        """Set user data pointer.

        Parameters
        ----------
        ptr : str
        """



from __future__ import annotations

from typing import Union

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import UNSET
from ..UtilityAndView.abaqusConstants import abaqusConstants as C
from .Load import Load


@abaqus_class_doc
class ConnectorMoment(Load):
    """The ConnectorMoment object stores the data for a connector moment. The ConnectorMoment object is derived
    from the Load object.

    .. note::
        This object can be accessed by::

            import load
            mdb.models[name].loads[name]
    """

    #: A String specifying the load repository key.
    name: str = ""

    #: A String specifying the name of the assembled fastener to which the load will be
    #: applied. This argument is not valid when **region** is specified. When this argument is
    #: specified, **fastenerSetName** must also be specified. The default value is an empty
    #: string.
    fastenerName: str = ""

    #: A String specifying the assembled fastener template model set to which the load will be
    #: applied. This argument is not valid when **region** is specified. When this argument is
    #: specified, **fastenerName** must also be specified. The default value is an empty string.
    fastenerSetName: str = ""

    #: A Region object specifying the region to which the load is applied.
    region: Region = Region()

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        region: str = "",
        fastenerName: str = "",
        fastenerSetName: str = "",
        m1: float | None = None,
        m2: float | None = None,
        m3: float | None = None,
        amplitude: str = UNSET,
    ):
        """This method creates a ConnectorMoment object on a wire region. Alternatively, the load may also be
        applied to a wire set referenced from an assembled fastener template model.

        .. note::
            This function can be accessed by::

                mdb.models[name].ConnectorMoment

        Parameters
        ----------
        name
            A String specifying the load repository key.
        createStepName
            A String specifying the name of the step in which the load is created.
        region
            The wire region to which the load is applied. This argument is not valid when
            **fastenerName** and **fastenerSetName** are specified.
        fastenerName
            A String specifying the name of the assembled fastener to which the load will be
            applied. This argument is not valid when **region** is specified. When this argument is
            specified, **fastenerSetName** must also be specified. The default value is an empty
            string.
        fastenerSetName
            A String specifying the assembled fastener template model set to which the load will be
            applied. This argument is not valid when **region** is specified. When this argument is
            specified, **fastenerName** must also be specified. The default value is an empty string.
        m1
            A Float or a Complex specifying the moment component in the connector's local
            4-direction.
        m2
            A Float or a Complex specifying the moment component in the connector's local
            5-direction.
        m3
            A Float or a Complex specifying the moment component in the connector's local
            6-direction.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.

        Returns
        -------
        ConnectorMoment
            A ConnectorMoment object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        region: str = "",
        fastenerName: str = "",
        fastenerSetName: str = "",
        m1: float | None = None,
        m2: float | None = None,
        m3: float | None = None,
        amplitude: str = UNSET,
    ):
        """This method modifies the data for an existing ConnectorMoment object in the step where it is created.

        Parameters
        ----------
        region
            The wire region to which the load is applied. This argument is not valid when
            **fastenerName** and **fastenerSetName** are specified.
        fastenerName
            A String specifying the name of the assembled fastener to which the load will be
            applied. This argument is not valid when **region** is specified. When this argument is
            specified, **fastenerSetName** must also be specified. The default value is an empty
            string.
        fastenerSetName
            A String specifying the assembled fastener template model set to which the load will be
            applied. This argument is not valid when **region** is specified. When this argument is
            specified, **fastenerName** must also be specified. The default value is an empty string.
        m1
            A Float or a Complex specifying the moment component in the connector's local
            4-direction.
        m2
            A Float or a Complex specifying the moment component in the connector's local
            5-direction.
        m3
            A Float or a Complex specifying the moment component in the connector's local
            6-direction.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(
        self,
        stepName: str,
        m1: Union[Literal[C.FREED, C.UNCHANGED], float] = ...,
        m2: Union[Literal[C.FREED, C.UNCHANGED], float] = ...,
        m3: Union[Literal[C.FREED, C.UNCHANGED], float] = ...,
        amplitude: str = "",
    ):
        """This method modifies the propagating data for an existing ConnectorMoment object in the specified
        step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the load is modified.
        m1
            A Float, a Complex, or a SymbolicConstant specifying the moment component in the
            connector's local 4-direction. Possible values for the SymbolicConstant are UNCHANGED
            and FREED. UNCHANGED should be used if the load component is propagated from the
            previous static analysis step. Use FREED to remove a previously defined load component.
        m2
            A Float, a Complex, or a SymbolicConstant specifying the moment component in the
            connector's local 5-direction. Possible values for the SymbolicConstant are UNCHANGED
            and FREED. UNCHANGED should be used if the load component is propagated from the
            previous static analysis step. Use FREED to remove a previously defined load component.
        m3
            A Float, a Complex, or a SymbolicConstant specifying the moment component in the
            connector's local 6-direction. Possible values for the SymbolicConstant are UNCHANGED
            and FREED. UNCHANGED should be used if the load component is propagated from the
            previous static analysis step. Use FREED to remove a previously defined load component.
        amplitude
            A String or a SymbolicConstant specifying the name of the amplitude reference. Possible
            values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED should be used if the
            amplitude is propagated from the previous static analysis step. FREED should be used if
            the load is changed to have no amplitude reference. You should provide the **amplitude**
            argument only if it is valid for the specified step.
        """
        ...



from __future__ import annotations

from .constants import DEFAULT_PAD
from .FXComposite import FXComposite
from .FXObject import FXObject
from .FXProgressBar import FXProgressBar

#: Percentage complete mode.
AFXPROGRESSBAR_PERCENTAGE: int = hash("AFXPROGRESSBAR_PERCENTAGE")

#: Horizontal display.
AFXPROGRESSBAR_HORIZONTAL: int = hash("AFXPROGRESSBAR_HORIZONTAL")

#: Vertical display.
AFXPROGRESSBAR_VERTICAL: int = hash("AFXPROGRESSBAR_VERTICAL")

#: Scanner mode.
AFXPROGRESSBAR_SCANNER: int = hash("AFXPROGRESSBAR_SCANNER")

#: Iterator mode.
AFXPROGRESSBAR_ITERATOR: int = hash("AFXPROGRESSBAR_ITERATOR")


class AFXProgressBar(FXProgressBar):
    """This class contains a progress bar, which can present work-in-progress in a number of different
    styles."""

    def __init__(
        self,
        p: FXComposite,
        tgt: FXObject | None = None,
        sel: int = 0,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_PAD,
        pr: int = DEFAULT_PAD,
        pt: int = DEFAULT_PAD,
        pb: int = DEFAULT_PAD,
    ):
        """Constructor.

        Parameters
        ----------
        p : FXComposite
            Parent widget.
        tgt : FXObject | None
            Message target.
        sel : int
            Message ID.
        x : int
            X coordinate of origin.
        y : int
            Y coordinate of origin.
        w : int
            Width of the widget.
        h : int
            Height of the widget.
        pl : int
            Left padding (margin).
        pr : int
            Right padding (margin).
        pt : int
            Top padding (margin).
        pb : int
            Bottom padding (margin).
        """

    def create(self):
        """Creates the progress bar.

        Reimplemented from FXProgressBar.
        """

    def getBarStyle(self):
        """Returns the progress bar style.

        Reimplemented from FXProgressBar.
        """

    def getDefaultHeight(self):
        """Returns the default height.

        Reimplemented from FXProgressBar.
        """

    def getDefaultWidth(self):
        """Returns the default width.

        Reimplemented from FXProgressBar.
        """

    def getNumCursorBoxes(self):
        """Returns the number of cursor boxes displayed."""

    def getProgress(self):
        """Returns the current progress amount.

        Reimplemented from FXProgressBar.
        """

    def getTotal(self):
        """Returns the total progress amount.

        Reimplemented from FXProgressBar.
        """

    def hide(self):
        """Hides the progress bar.

        Reimplemented from FXWindow.
        """

    def hideNumber(self):
        """Hides the progress bar iteration or percentage text.

        Reimplemented from FXProgressBar.
        """

    def setBarStyle(self, style: int):
        """Sets the progress bar style.

        Parameters
        ----------
        style : int
            Style flag.
        """

    def setNumCursorBoxes(self, nb: int):
        """Sets the number of cursor boxes to display.

        Parameters
        ----------
        nb : int
            Number of boxes.
        """

    def setProgress(self, value: int):
        """Sets the current progress amount that is used by a progress bar in either iteration or percentage
        mode; the progress amount is ingored by a progress bar in scanner mode. Reimplemented from
        FXProgressBar.

        Parameters
        ----------
        value : int
        """

    def setTotal(self, value: int):
        """Sets the total progress amount that is used by a progress bar in either iteration or percentage mode;
        the progress amount is ingored by a progress bar in scanner mode. Reimplemented from FXProgressBar.

        Parameters
        ----------
        value : int
        """

    def show(self):
        """Shows the progress bar.

        Reimplemented from FXWindow.
        """

    def showNumber(self, style: int = AFXPROGRESSBAR_PERCENTAGE):
        """Shows the progress iteration or percentage text.

        Parameters
        ----------
        style : int
            Style flag.
        """



from __future__ import annotations

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import (
    CONSTANT,
    DEFAULT,
    GRADIENT,
    NO_IDEALIZATION,
    OFF,
    SIMPSON,
    UNIFORM,
    Boolean,
    SymbolicConstant,
)
from ..UtilityAndView.abaqusConstants import abaqusConstants as C
from .LayerPropertiesArray import LayerPropertiesArray
from .RebarLayers import RebarLayers
from .ShellSection import ShellSection
from .TransverseShearShell import TransverseShearShell


@abaqus_class_doc
class GeometryShellSection(ShellSection):
    """The GeometryShellSection object defines the properties of a geometry shell section. The
    GeometryShellSection object has no explicit constructor and no methods. The GeometryShellSection object is
    an abstract base type. The GeometryShellSection object is derived from the ShellSection object.

    .. note::
        This object can be accessed by::

            import section
            mdb.models[name].parts[name].compositeLayups[i].section
            mdb.models[name].sections[name]
            import odbSection
            session.odbs[name].sections[name]
    """

    #: A String specifying the repository key.
    name: str = ""

    #: A SymbolicConstant specifying the distribution used for defining the thickness of the
    #: elements. Possible values are UNIFORM, ANALYTICAL_FIELD, DISCRETE_FIELD,
    #: NODAL_ANALYTICAL_FIELD, and NODAL_DISCRETE_FIELD. The default value is UNIFORM.
    thicknessType: SymbolicConstant = UNIFORM

    #: A Boolean specifying whether the shell section properties are specified by the user
    #: prior to the analysis (ON) or integrated during the analysis (OFF). The default value is
    #: OFF.
    preIntegrate: Boolean = OFF

    #: A SymbolicConstant specifying whether to use the default value for the Poisson's ratio.
    #: Possible values are:DEFAULT, specifying that the default value for the Poisson's ratio
    #: is 0.5 in an Abaqus/Standard analysis and is obtained from the material definition in an
    #: Abaqus/Explicit analysis.VALUE, specifying that the Poisson's ratio used in the analysis
    #: is the value provided in **poisson**.The default value is DEFAULT.
    poissonDefinition: SymbolicConstant = DEFAULT

    #: A Float specifying the Poisson's ratio. Possible values are −1.0 ≤ **poisson** ≤ 0.5.
    #: This argument is valid only when **poissonDefinition** = VALUE. The default value is 0.5.
    poisson: float = 0

    #: A SymbolicConstant specifying the shell section integration rule. Possible values are
    #: SIMPSON and GAUSS. The default value is SIMPSON.
    integrationRule: SymbolicConstant = SIMPSON

    #: A SymbolicConstant specifying the mode used for temperature and field variable input
    #: across the section thickness. Possible values are GRADIENT and POINTWISE. The default
    #: value is GRADIENT.
    temperature: SymbolicConstant = GRADIENT

    #: A SymbolicConstant specifying the mechanical idealization used for the section
    #: calculations. This member is only applicable when **preIntegrate** is set to ON. Possible
    #: values are NO_IDEALIZATION, SMEAR_ALL_LAYERS, MEMBRANE, and BENDING. The default value
    #: is NO_IDEALIZATION.
    idealization: SymbolicConstant = NO_IDEALIZATION

    #: None or an Int specifying the number of temperature points to be input. This argument is
    #: valid only when **temperature** = POINTWISE. The default value is None.
    nTemp: int | None = None

    #: None or a Float specifying the effective thickness modulus. This argument is relevant
    #: only for continuum shells and must be used in conjunction with the argument **poisson**.
    #: The default value is None.
    thicknessModulus: float | None = None

    #: A Boolean specifying whether or not to use the value of **density**. The default value is
    #: OFF.
    useDensity: Boolean = OFF

    #: A Float specifying the value of density to apply to this section. The default value is
    #: 0.0.
    density: float = 0

    #: A String specifying the name of the AnalyticalField or DiscreteField object used to
    #: define the thickness of the shell elements. The **thicknessField** argument applies only
    #: when **thicknessType** = ANALYTICAL_FIELD or **thicknessType** = DISCRETE_FIELD. The default
    #: value is an empty string.
    thicknessField: str = ""

    #: A RebarLayers object specifying reinforcement properties.
    rebarLayers: RebarLayers = RebarLayers(CONSTANT, [])

    #: A String specifying the name of the AnalyticalField or DiscreteField object used to
    #: define the thickness of the shell elements at each node. The **nodalThicknessField**
    #: argument applies only when **thicknessType** = NODAL_ANALYTICAL_FIELD or
    #: **thicknessType** = NODAL_DISCRETE_FIELD. The default value is an empty string.
    nodalThicknessField: str = ""

    #: A TransverseShearShell object specifying the transverse shear stiffness properties.
    transverseShear: TransverseShearShell

    @abaqus_method_doc
    def __init__(
        self,
        nodalThicknessField: str = "",
        thicknessField: str = "",
        thicknessType: Literal[
            C.DISCRETE_FIELD, C.NODAL_ANALYTICAL_FIELD, C.ANALYTICAL_FIELD, C.UNIFORM, C.NODAL_DISCRETE_FIELD
        ] = UNIFORM,
        preIntegrate: Boolean = OFF,
        poissonDefinition: Literal[C.DEFAULT] = DEFAULT,
        poisson: float = 0,
        integrationRule: Literal[C.GAUSS, C.SIMPSON] = SIMPSON,
        temperature: Literal[C.GRADIENT, C.POINTWISE] = GRADIENT,
        nTemp: int | None = None,
        thicknessModulus: float | None = None,
        useDensity: Boolean = OFF,
        density: float = 0,
    ):
        """This method creates a GeometryShellSection object.

        .. note::
            This function can be accessed by::

                mdb.models[name].parts[name].compositeLayups[name].Section

        Parameters
        ----------
        nodalThicknessField
            A String specifying the name of the AnalyticalField or DiscreteField object used to
            define the thickness of the shell elements at each node. The **nodalThicknessField**
            argument applies only when **thicknessType** = NODAL_ANALYTICAL_FIELD or
            **thicknessType** = NODAL_DISCRETE_FIELD. The default value is an empty string.
        thicknessField
            A String specifying the name of the AnalyticalField or DiscreteField object used to
            define the thickness of the shell elements. The **thicknessField** argument applies only
            when **thicknessType** = ANALYTICAL_FIELD or **thicknessType** = DISCRETE_FIELD. The default
            value is an empty string.
        thicknessType
            A SymbolicConstant specifying the distribution used for defining the thickness of the
            elements. Possible values are UNIFORM, ANALYTICAL_FIELD, DISCRETE_FIELD,
            NODAL_ANALYTICAL_FIELD, and NODAL_DISCRETE_FIELD. The default value is UNIFORM.
        preIntegrate
            A Boolean specifying whether the shell section properties are specified by the user
            prior to the analysis (ON) or integrated during the analysis (OFF). The default value is
            OFF.
        poissonDefinition
            A SymbolicConstant specifying whether to use the default value for the Poisson's ratio.
            Possible values are:DEFAULT, specifying that the default value for the Poisson's ratio
            is 0.5 in an Abaqus/Standard analysis and is obtained from the material definition in an
            Abaqus/Explicit analysis.VALUE, specifying that the Poisson's ratio used in the analysis
            is the value provided in **poisson**.The default value is DEFAULT.
        poisson
            A Float specifying the Poisson's ratio. Possible values are −1.0 ≤ **poisson** ≤ 0.5.
            This argument is valid only when **poissonDefinition** = VALUE. The default value is 0.5.
        integrationRule
            A SymbolicConstant specifying the shell section integration rule. Possible values are
            SIMPSON and GAUSS. The default value is SIMPSON.
        temperature
            A SymbolicConstant specifying the mode used for temperature and field variable input
            across the section thickness. Possible values are GRADIENT and POINTWISE. The default
            value is GRADIENT.
        nTemp
            None or an Int specifying the number of temperature points to be input. This argument is
            valid only when **temperature** = POINTWISE. The default value is None.
        thicknessModulus
            None or a Float specifying the effective thickness modulus. This argument is relevant
            only for continuum shells and must be used in conjunction with the argument **poisson**.
            The default value is None.
        useDensity
            A Boolean specifying whether or not to use the value of **density**. The default value is
            OFF.
        density
            A Float specifying the value of density to apply to this section. The default value is
            0.0.

        Returns
        -------
        GeometryShellSection
            A GeometryShellSection object.
        """
        ...

    @abaqus_method_doc
    def RebarLayers(
        self, rebarSpacing: Literal[C.LIFT_EQUATION, C.CONSTANT, C.ANGULAR], layerTable: LayerPropertiesArray
    ) -> RebarLayers:
        """This method creates a RebarLayers object.

        .. note::
            This function can be accessed by::

                mdb.models[name].parts[name].compositeLayups[name].Section

        Parameters
        ----------
        rebarSpacing
            A SymbolicConstant specifying the type of rebar geometry. Possible values are CONSTANT,
            ANGULAR, and LIFT_EQUATION.
        layerTable
            A LayerPropertiesArray object specifying the layers of reinforcement.

        Returns
        -------
        RebarLayers
            A RebarLayers object.
        """
        self.rebarLayers = rebarLayers = RebarLayers(rebarSpacing, layerTable)
        return rebarLayers



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import OFF, Boolean


@abaqus_class_doc
class Imperfection:
    """The Imperfection object is the abstract base type for FileImperfection, InputImperfection, and
    DataImperfection.

    .. note::
        This object can be accessed by::

            import assembly
            mdb.models[name].rootAssembly.engineeringFeatures.imperfections[name]

    .. versionadded:: 2023
        The ``Imperfection`` class was added.
    """

    #: A String specifying the repository key.
    name: str = ""

    #: A Boolean specifying whether the fastener is suppressed or not. The default value is
    #: OFF.
    suppressed: Boolean = OFF

    @abaqus_method_doc
    def resume(self):
        """This method resumes the imperfection that was previously suppressed."""
        ...

    @abaqus_method_doc
    def suppress(self):
        """This method suppresses the imperfection."""
        ...



from __future__ import annotations

from .FXComposite import FXComposite
from .FXHorizontalFrame import FXHorizontalFrame

#: Information note.
NOTE_INFORMATION: int = hash("NOTE_INFORMATION")

#: Warning note.
NOTE_WARNING: int = hash("NOTE_WARNING")


class AFXNote(FXHorizontalFrame):
    """This class prefixes a given message string by either "Note:" or "Warning:"."""

    def __init__(self, p: FXComposite, message: str, opts: int = NOTE_INFORMATION, x: int = 0, y: int = 0):
        """Constructor.

        Parameters
        ----------
        p : FXComposite
            Parent widget.
        message : str
            Note message string.
        opts : int
            Options and hints.
        x : int
            X coordinate of origin.
        y : int
            Y coordinate of origin.
        """

    def create(self):
        """Creates the note.

        Reimplemented from FXComposite.
        """

    def detach(self):
        """Detaches the server-resources of the note.

        Reimplemented from FXComposite.
        """

    def disable(self):
        """Disables the note.

        Reimplemented from FXWindow.
        """

    def enable(self):
        """Enables the note.

        Reimplemented from FXWindow.
        """

    def getText(self):
        """Returns the note's message string."""

    def setText(self, message: str):
        """Sets the note's message string.

        Parameters
        ----------
        message : str
            Message.
        """



from __future__ import annotations

from .FXObject import FXObject


class AFXTarget(FXObject):
    """This class is the base class for all target objects."""

    #: Unspecified.
    UNSPECIFIED: int = hash("UNSPECIFIED")

    #: Integer.
    INT: int = hash("INT")

    #: Float.
    FLOAT: int = hash("FLOAT")

    #: String.
    STRING: int = hash("STRING")

    def __init__(self):
        """Constructor."""

    def connect(self, value: int):
        """Associates the data with an integer variable.

        Parameters
        ----------
        value : int
            Variable to be associated with.
        """

    def getSelector(self):
        """Returns the message ID of this target object."""

    def getTarget(self):
        """Returns the target of this target object."""

    def getType(self):
        """Returns the target type; this method is deprecated in Abaqus 6.6, and its use should be replaced by
        getTypeName()."""

    def getTypeName(self):
        """Returns the name of the target type.

        Implemented in AFXFloatTarget, AFXIntTarget, and AFXStringTarget.
        """

    def setSelector(self, msgId: int):
        """Sets the message ID of this target object.

        Parameters
        ----------
        msgId : int
            Message ID.
        """

    def setTarget(self, target: FXObject):
        """Sets the target of this target object.

        Parameters
        ----------
        target : FXObject
            Target.
        """
